@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 from django_spire.auth.controller.controller import BaseAuthController
 
 
 class BaseAiChatAuthController(BaseAuthController):
-    def can_delete(self):
+    def can_delete(self) -> bool:
         return self.request.user.has_perm('django_spire_ai_chat.delete_chat')
