@@ -1,7 +1,8 @@
-from django.urls import path, include
+from django.urls import include, path
 
 from django_spire.ai.chat.views import message_views
 
+
 app_name = 'message'
 
 urlpatterns = [
