@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 from django_spire.ai.prompt.bots import DandyPythonPromptBot
 
+
 def text_to_prompt_cli(prompt: str):
-    prompt = prompt
-    DandyPythonPromptBot().process(prompt)
+    bot = DandyPythonPromptBot()
+    bot.process(prompt)
