@@ -5,21 +5,15 @@ from django_spire.auth.user.models import AuthUser
 
 def create_user(
     username: str,
-    password: str,
     **kwargs
 ) -> AuthUser:
     user, created = AuthUser.objects.get_or_create(
         username=username,
         defaults={
-            # 'password': password,
             **kwargs
         }
     )
 
-    # if created:
-    #     user.set_password(password)
-    #     user.save()
-
     return user
 
 
