@@ -1,19 +1,17 @@
-from typing import Type
-
 from django.db.models.base import Model
 
-from dandy.llm import Prompt
+from dandy import Prompt
 
 
 class SeedingModelClassPromptFactory:
 
-    def __init__(self, model_class: Type[Model]):
+    def __init__(self, model_class: type[Model]):
         self.model_class = model_class
 
     def objective_prompt(
-            self,
-            model_description: str,
-            sector_description: str,
+        self,
+        model_description: str,
+        sector_description: str
     ) -> Prompt:
         model_name = self.model_class._meta.verbose_name_plural.title()
 
