@@ -7,6 +7,14 @@ class HelpDeskConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
     label = 'django_spire_help_desk'
     name = 'django_spire.help_desk'
+    MODEL_PERMISSIONS = (
+        {
+            'name': 'help_desk',
+            'verbose_name': 'Help Desk',
+            'model_class_path': 'django_spire.help_desk.models.HelpDeskTicket',
+            'is_proxy_model': False,
+        },
+    )
 
     REQUIRED_APPS = ('django_spire_core',)
     URLPATTERNS_INCLUDE = 'django_spire.help_desk.urls'
