@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from django.core.handlers.wsgi import WSGIRequest
 from django.shortcuts import get_object_or_404
 from django.template.response import TemplateResponse
@@ -18,16 +20,8 @@ def detail_view(request: WSGIRequest, pk: int) -> TemplateResponse:
         breadcrumbs.add_breadcrumb(name='Knowledge')
         breadcrumbs.add_breadcrumb(
             name='Collections',
-            href=reverse('django_spire:knowledge:collection:page:list')
+            href=reverse('django_spire:knowledge:page:home')
         )
-        breadcrumbs.add_breadcrumb(
-            name=entry.collection.name,
-            href=reverse(
-                'django_spire:knowledge:collection:page:detail',
-                kwargs={'pk': entry.collection.pk}
-            )
-        )
-        breadcrumbs.add_breadcrumb(name=f'View {entry.name}')
 
     return portal_views.detail_view(
         request,
