@@ -18,9 +18,6 @@ def delete_view(request: WSGIRequest, pk: int) -> TemplateResponse:
         delete_func=entry.services.processor.set_deleted,
         return_url=request.GET.get(
             'return_url',
-            reverse(
-                'django_spire:knowledge:collection:page:detail',
-                kwargs={'pk': entry.collection.pk}
-            )
+            reverse('django_spire:knowledge:page:home')
         )
     )
