@@ -18,26 +18,9 @@ def file_list_view(request: WSGIRequest, collection_pk: int = 0) -> TemplateResp
 
         breadcrumbs.add_breadcrumb(
             name='Collections',
-            href=reverse('django_spire:knowledge:collection:page:list')
+            href=reverse('django_spire:knowledge:page:home')
         )
 
-        if collection.parent_id is not None:
-            parent = collection.parent
-            breadcrumbs.add_breadcrumb(
-                name=parent.name,
-                href=reverse(
-                    viewname='django_spire:knowledge:collection:page:detail',
-                    kwargs={'pk': parent.pk}
-                )
-            )
-
-        breadcrumbs.add_breadcrumb(
-            name=collection.name,
-            href=reverse(
-                viewname='django_spire:knowledge:collection:page:detail',
-                kwargs={'pk': collection.pk}
-            )
-        )
         breadcrumbs.add_breadcrumb(name='Importing Files')
 
     return TemplateResponse(
