@@ -1,6 +1,6 @@
-from typing import List
+from __future__ import annotations
 
-from dandy.intel import BaseIntel, BaseListIntel
+from dandy import BaseIntel, BaseListIntel
 
 from django_spire.knowledge.intelligence.intel.collection_intel import CollectionIntel
 
@@ -11,4 +11,4 @@ class EntryIntel(BaseIntel):
 
 
 class EntriesIntel(BaseListIntel[EntryIntel]):
-    entry_intel_list: List[EntryIntel]
\ No newline at end of file
+    entry_intel_list: list[EntryIntel]
